module.exports = defineTest({
	description: 'handles getters defined on arrays'
});
